@@ -178,17 +178,17 @@ sub prepare_Tracking_Env() {
 	my $iniEdtk	=ini_Edtk_Conf();
 	conf_To_Env($iniEdtk, 'ENVDESC');
 	conf_To_Env($iniEdtk, 'EDTK_DB');
-	maj_sans_accents($ENV{EDTK_TRACK_MODE});
+	oe_uc_sans_accents($ENV{EDTK_TRACK_MODE});
 
 1;
 }
 
 sub open_Tracking_Env(){
 	if ($ENV{EDTK_TRACK_MODE} =~/FDB/i){
-		# DB FILE NOWTIME/PROCESS
+		# DB FILE oe_now_time/PROCESS
 		$ENV{EDTK_DBI_DNS}=~s/(.+)\.(\w+)$/$1\.$ED_TSTAMP\.$ED_PROC\.$2/;
-		warn "INFO tracking to $ENV{EDTK_DSN_DBI}\n";
-		create_Track_Table($ENV{EDTK_DSN_DBI});
+		warn "INFO tracking to $ENV{EDTK_DBI_DSN}\n";
+		create_Track_Table($ENV{EDTK_DBI_DSN});
 		open_DBI();
 			
 	} elsif ($ENV{EDTK_TRACK_MODE} =~/LOG/i){
@@ -216,12 +216,12 @@ sub open_DBI(){
 			RaiseError => 	$ENV{EDTK_DBI_RaiseError},
 			PrintError => 	$ENV{EDTK_DBI_PrintError}};
 
-	$DBH = DBI->connect(		$ENV{EDTK_DSN_DBI},
-					$ENV{EDTK_DSN_DBI_USER},
-					$ENV{EDTK_DSN_DBI_PASS}
+	$DBH = DBI->connect(		$ENV{EDTK_DBI_DSN},
+					$ENV{EDTK_DBI_DSN_USER},
+					$ENV{EDTK_DBI_DSN_PASS}
 			#		,$dbargs
 				)
-			or die "ERR no connexion to $ENV{EDTK_DSN_DBI} " . DBI->errstr;
+			or die "ERR no connexion to $ENV{EDTK_DBI_DSN} " . DBI->errstr;
 
 1;
 }
@@ -236,7 +236,7 @@ sub init_Tracking(;@){
 	define_Job_Evt ($Typ_Job);	# S(pool) by default
 	define_Job_User($Job_User);	# user job request, by default 'None'
 	$ED_HOST	=hostname();
-	$ED_TSTAMP	=nowTime();
+	$ED_TSTAMP	=oe_now_time();
 	$ED_PROC	=$$;
 	$ED_SEQ		=0;			# (dynamic, private)
 	$ED_SNGL_ID	= md5_base64($ED_HOST.$ED_TSTAMP.$ED_PROC);
@@ -273,7 +273,7 @@ sub track_Obj (;@){
 	@ED_K_VAL =@_;
 
 	undef @TRACKED_OBJ;
-	push (@TRACKED_OBJ, nowTime());
+	push (@TRACKED_OBJ, oe_now_time());
 	push (@TRACKED_OBJ, $ED_USER);
 	push (@TRACKED_OBJ, $ED_SEQ);
 	push (@TRACKED_OBJ, $ED_SNGL_ID);
@@ -360,7 +360,7 @@ sub define_Track_Key ($;$) {
 	if ($value) { $ED_K_NAME[$indice] =$value; }
 
 	$ED_K_NAME[$indice] =~ s/\s/\_/g;
-	maj_sans_accents($ED_K_NAME[$indice]);
+	oe_uc_sans_accents($ED_K_NAME[$indice]);
 
 return $ED_K_NAME[$indice];
 }
@@ -416,12 +416,12 @@ sub test_exist_table(){
 	my $dbargs = {	AutoCommit => $ENV{EDTK_DBI_AutoCommit},
 				RaiseError => $ENV{EDTK_DBI_RaiseError},
 				PrintError => $ENV{EDTK_DBI_PrintError}};
-	$DBH = DBI->connect($ENV{EDTK_DSN_DBI},
-					$ENV{EDTK_DSN_DBI_USER},
-					$ENV{EDTK_DSN_DBI_PASS}
+	$DBH = DBI->connect($ENV{EDTK_DBI_DSN},
+					$ENV{EDTK_DBI_DSN_USER},
+					$ENV{EDTK_DBI_DSN_PASS}
 					,$dbargs
 				)
-			or die "ERR no connexion to $ENV{EDTK_DSN_DBI} " . DBI->errstr;
+			or die "ERR no connexion to $ENV{EDTK_DBI_DSN} " . DBI->errstr;
 
 	my $request="select * from $ENV{EDTK_DBI_TABLENAME}";
 
@@ -462,11 +462,11 @@ sub create_Track_Table(){
 	my $dbargs = {	AutoCommit => 0,
 				RaiseError => 0,
 				PrintError => 0 };
-	$DBH = DBI->connect($ENV{EDTK_DSN_DBI},
-					$ENV{EDTK_DSN_DBI_USER},
-					$ENV{EDTK_DSN_DBI_PASS},
+	$DBH = DBI->connect($ENV{EDTK_DBI_DSN},
+					$ENV{EDTK_DBI_DSN_USER},
+					$ENV{EDTK_DBI_DSN_PASS},
 					$dbargs)
-			or die "ERR no connexion to $ENV{EDTK_DSN_DBI} " . DBI->errstr;
+			or die "ERR no connexion to $ENV{EDTK_DBI_DSN} " . DBI->errstr;
 
 	my $struct="CREATE TABLE $ENV{EDTK_DBI_TABLENAME} ";
 	$struct .="( ED_TSTAMP NUMBER(14)  NOT NULL";	# interesting for formated date and interval search
@@ -510,7 +510,7 @@ sub drop_Track_Table(){
 	&prepare_Tracking_Env();
 	&open_DBI();
 	
-	warn "=> Drop table $ENV{EDTK_DBI_TABLENAME} from $ENV{EDTK_DSN_DBI}, if exist\n\n";
+	warn "=> Drop table $ENV{EDTK_DBI_TABLENAME} from $ENV{EDTK_DBI_DSN}, if exist\n\n";
 	$DBH->do("DROP TABLE $ENV{EDTK_DBI_TABLENAME}");
 	$DBH->disconnect;
 
